@@ -56,7 +56,7 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock org.
 #include "interface-applet-signals.h"
 #include "applet-dbus.h"
 
-#define DISTANT_DIR "3.2.0"
+#define DISTANT_DIR "3.3.0"
 #define GETTEXT_NAME_EXTRAS "cairo-dock-plugins-extra"
 #define LOCALE_DIR_NAME "locale"
 
@@ -88,7 +88,7 @@ static void cd_dbus_main_init (dbusMainObject *pMainObject)
  /// MODULE REGISTERING ///
 //////////////////////////
 
-static void _on_init_module (CairoDockModuleInstance *pModuleInstance, GKeyFile *pKeyFile)
+static void _on_init_module (GldiModuleInstance *pModuleInstance, GKeyFile *pKeyFile)
 {
 	cd_debug ("%s ()", __func__);
 	
@@ -113,26 +113,20 @@ static void _on_init_module (CairoDockModuleInstance *pModuleInstance, GKeyFile
 	//\_____________ On (re)lance l'executable de l'applet.
 	cd_dbus_launch_applet_process (pModuleInstance, pDbusApplet);
 }
-static gboolean _cd_dbus_register_new_module (const gchar *cModuleName, const gchar *cDescription, const gchar *cAuthor, const gchar *cVersion, gint iCategory, const gchar *cIconName, const gchar *cShareDataDir, gboolean bMultiInstance, gboolean bActAsLauncher)
+static gboolean _cd_dbus_register_new_module (const gchar *cModuleName, const gchar *cDescription, const gchar *cAuthor, const gchar *cVersion, gint iCategory, const gchar *cIconName, const gchar *cTitle, const gchar *cShareDataDir, gboolean bMultiInstance, gboolean bActAsLauncher)
 {
 	cd_message ("%s (%s)", __func__, cModuleName);
 	
 	//\____________ on cree et on enregistre un nouveau module s'il n'existe pas deja.
-	CairoDockModule *pModule = cairo_dock_find_module_from_name (cModuleName);
+	GldiModule *pModule = gldi_module_get (cModuleName);
 	if (pModule != NULL)  // le module existe deja, rien a faire.
 	{
 		cd_warning ("this module (%s) is already registered", cModuleName);
-		if (pModule->cSoFilePath != NULL)
-		{
-			cd_warning ("an installed module already exists with this name (%s).", cModuleName);
-			return FALSE;
-		}
+		return FALSE;
 	}
 	else  // on enregistre ce nouveau module.
 	{
-		pModule = gldi_object_new (CairoDockModule, &myModulesMgr);
-		CairoDockVisitCard *pVisitCard = g_new0 (CairoDockVisitCard, 1);
-		pModule->pVisitCard = pVisitCard;
+		GldiVisitCard *pVisitCard = g_new0 (GldiVisitCard, 1);
 		pVisitCard->cModuleName = g_strdup (cModuleName);
 		pVisitCard->iMajorVersionNeeded = 2;
 		pVisitCard->iMinorVersionNeeded = 1;
@@ -152,17 +146,19 @@ static gboolean _cd_dbus_register_new_module (const gchar *cModuleName, const gc
 		pVisitCard->iSizeOfConfig = 4;  // au cas ou ...
 		pVisitCard->iSizeOfData = 4;  // au cas ou ...
 		pVisitCard->cDescription = g_strdup (cDescription);
-		pVisitCard->cTitle = g_strdup (dgettext (pVisitCard->cGettextDomain, cModuleName));
+		pVisitCard->cTitle = cTitle ?
+			g_strdup (dgettext (pVisitCard->cGettextDomain, cTitle)) :
+			g_strdup (cModuleName);
 		pVisitCard->iContainerType = CAIRO_DOCK_MODULE_CAN_DOCK | CAIRO_DOCK_MODULE_CAN_DESKLET;
 		pVisitCard->bMultiInstance = bMultiInstance;
 		pVisitCard->bActAsLauncher = bActAsLauncher;  // ex.: XChat controls xchat/xchat-gnome, but it does that only after initializing; we need to know if it's a launcher before the taskbar is loaded, hence this parameter.
-		pModule->pInterface = g_new0 (CairoDockModuleInterface, 1);
-		pModule->pInterface->initModule = _on_init_module;
-		pModule->pInterface->stopModule = cd_dbus_emit_on_stop_module;
-		pModule->pInterface->reloadModule = cd_dbus_emit_on_reload_module;
-		if (! cairo_dock_register_module (pModule))
+		GldiModuleInterface *pInterface = g_new0 (GldiModuleInterface, 1);
+		pInterface->initModule = _on_init_module;
+		pInterface->stopModule = cd_dbus_emit_on_stop_module;
+		pInterface->reloadModule = cd_dbus_emit_on_reload_module;
+		pModule = gldi_module_new (pVisitCard, pInterface);
+		if (! pModule)
 		{
-			cairo_dock_free_module (pModule);
 			cd_warning ("registration of '%s' has failed.", cModuleName);
 			return FALSE;
 		}
@@ -219,6 +215,12 @@ gboolean cd_dbus_register_module_in_dir (const gchar *cModuleName, const gchar *
 		g_free (cIconName);
 		cIconName = NULL;
 	}
+	gchar *cTitle = g_key_file_get_string (pKeyFile, "Register", "title", NULL);  // NULL if not specified
+	if (cTitle && *cTitle == '\0')
+	{
+		g_free (cTitle);
+		cTitle = NULL;
+	}
 	
 	gboolean bMultiInstance = g_key_file_get_boolean (pKeyFile, "Register", "multi-instance", NULL);  // false if not specified
 	
@@ -228,11 +230,12 @@ gboolean cd_dbus_register_module_in_dir (const gchar *cModuleName, const gchar *
 	
 	g_key_file_free (pKeyFile);
 	
-	gboolean bActivationOk = _cd_dbus_register_new_module (cModuleName, cDescription, cAuthor, cVersion, iCategory, cIconName, cShareDataDir, bMultiInstance, bActAsLauncher);
+	gboolean bActivationOk = _cd_dbus_register_new_module (cModuleName, cDescription, cAuthor, cVersion, iCategory, cIconName, cTitle, cShareDataDir, bMultiInstance, bActAsLauncher);
 	g_free (cDescription);
 	g_free (cAuthor);
 	g_free (cVersion);
 	g_free (cIconName);
+	g_free (cTitle);
 	g_free (cShareDataDir);
 	g_free (cFilePath);
 	return bActivationOk;
@@ -289,27 +292,27 @@ static void _get_package_path (gchar *cModuleName)
 }
 static gboolean _apply_package_update (gchar *cModuleName)
 {
-	CairoDockModule *pModule = cairo_dock_find_module_from_name (cModuleName);
+	GldiModule *pModule = gldi_module_get (cModuleName);
 	
 	if (pModule && pModule->pInstancesList != NULL)  // applet active => reload it (pModule can be NULL in case of "locale").
 	{
 		cd_debug ("*** applet '%s' is active, reload it", cModuleName);
-		CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
+		GldiModuleInstance *pModuleInstance = pModule->pInstancesList->data;
 		Icon *pIcon = pModuleInstance->pIcon;
-		CairoContainer *pContainer = pModuleInstance->pContainer;
+		GldiContainer *pContainer = pModuleInstance->pContainer;
 		
 		// unregister the module, since anything can have changed, including its definition.
-		cairo_dock_unregister_module (cModuleName);  // stoppe le module (toutes les instances), ce qui appelle stop_module, qui emet le signal 'stop' vers l'applet distante (qui du coup quitte), et enleve le module de la table. L'objet distant est detruit durant le stop.
+		gldi_object_unref (GLDI_OBJECT(pModule));  // stoppe le module (toutes les instances), ce qui appelle stop_module, qui emet le signal 'stop' vers l'applet distante (qui du coup quitte). L'objet distant est detruit durant le stop.
 		
 		// clean the dock from the remaining icon.
 		if (pIcon != NULL && pContainer != NULL)  // par contre les icones restent, mais ne sont plus des applets (elles ont perdu leur module). On fait donc le menage.
 		{
 			if (CAIRO_DOCK_IS_DOCK (pContainer))
 			{
-				cairo_dock_detach_icon_from_dock (pIcon, CAIRO_DOCK (pContainer));
-				cairo_dock_free_icon (pIcon);
-				cairo_dock_update_dock_size (CAIRO_DOCK (pContainer));
-				cairo_dock_redraw_container (pContainer);
+				gldi_icon_detach (pIcon);
+				gldi_object_unref (GLDI_OBJECT(pIcon));
+				///cairo_dock_update_dock_size (CAIRO_DOCK (pContainer));
+				///cairo_dock_redraw_container (pContainer);
 			}
 		}
 		
@@ -319,9 +322,9 @@ static gboolean _apply_package_update (gchar *cModuleName)
 		g_free (cThirdPartyPath);
 		
 		// and activate it again.
-		pModule = cairo_dock_find_module_from_name (cModuleName);  // the module has been destroyed previously, so grab it again.
+		pModule = gldi_module_get (cModuleName);  // the module has been destroyed previously, so grab it again.
 		g_return_val_if_fail (pModule != NULL, TRUE);
-		cairo_dock_activate_module (pModule, NULL);
+		gldi_module_activate (pModule);
 	}
 	
 	// get corresponding task and free it.
@@ -530,9 +533,27 @@ void cd_dbus_launch_service (void)
 				cd_warning ("couldn't create '%s'; third-party applets can't be added", cUserAppletsFolder);
 		}
 		g_free (cUserAppletsFolder);
-		
-		if (g_mkdir (cLocaleDir, 7*8*8+7*8+5) != 0)  // create an empty folder; since there is no date file, the "locale" package will be seen as "to be updated" by the package manager, and will therefore download it.
+
+		/*
+		 * create an empty folder; since there is no date file, the "locale"
+		 * package will be seen as "to be updated" by the package manager, and
+		 * will therefore download it.
+		 * But if last-modif file is not available, it will be seen as "to be
+		 * updated" only if the external package is younger than one month:
+		 *  => cairo-dock-packages.c:_cairo_dock_parse_package_list
+		 * Solution: added a file with "0" to force the download
+		 */
+		if (g_mkdir (cLocaleDir, 7*8*8+7*8+5) != 0)
 			cd_warning ("couldn't create '%s'; applets won't be translated", cLocaleDir);
+		else
+		{
+			gchar *cVersionFile = g_strdup_printf ("%s/last-modif", cLocaleDir);
+			g_file_set_contents (cVersionFile,
+					"0",
+					-1,
+					NULL);
+			g_free (cVersionFile);
+		}
 	}
 	bindtextdomain (GETTEXT_NAME_EXTRAS, cLocaleDir);  // bind the applets' domain to the user locale folder.
 	bind_textdomain_codeset (GETTEXT_NAME_EXTRAS, "UTF-8");
