@@ -141,7 +141,7 @@ void vfs_backend_get_file_info (const gchar *cBaseURI, gchar **cName, gchar **cU
 				GString *sURI = g_string_new (cSplit[0]);
 				for (i = 1; cSplit[i] != NULL; i ++)
 				{
-					cd_message ("%d) %s\n", i, cSplit[i]);
+					cd_message ("%d) %s", i, cSplit[i]);
 					g_string_append_printf (sURI, "%%2520%s", cSplit[i]);
 				}
 				cFullURI = sURI->str;
@@ -299,7 +299,7 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 			
 			icon = cairo_dock_create_dummy_launcher (NULL, NULL, NULL, NULL, 0);
 			icon->cBaseURI = cFileURI;
-			icon->iType = iNewIconsType;
+			icon->iGroup = iNewIconsType;
 			if ( (valid & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) && strcmp (info->mime_type, "application/x-desktop") == 0)
 			{
 				gboolean bIsDirectory = FALSE;
