@@ -1,4 +1,4 @@
-/**
+	/**
 * This file is a part of the Cairo-Dock project
 *
 * Copyright : (C) see the 'copyright' file.
@@ -260,8 +260,8 @@ static void _switch_to_user (GtkMenuItem *menu_item, gchar *cUserName)
 		cd_logout_switch_to_guest ();
 	}
 }
-static GtkWidget *pShutdownMenuItem;
-static GtkWidget *_build_menu (void)
+
+static GtkWidget *_build_menu (GtkWidget **pShutdownMenuItem)
 {
 	GtkWidget *pMenu = gldi_menu_new (myIcon);
 	
@@ -273,7 +273,7 @@ static GtkWidget *_build_menu (void)
 	g_free (cImagePath);
 	if (!myData.bCanStop && ! myConfig.cUserActionShutdown)
 		gtk_widget_set_sensitive (pMenuItem, FALSE);
-	pShutdownMenuItem = pMenuItem;
+	*pShutdownMenuItem = pMenuItem;
 	
 	cImagePath = _check_icon (GTK_STOCK_REFRESH, myData.iDesiredIconSize);
 	pMenuItem = CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Restart"), cImagePath ? cImagePath : MY_APPLET_SHARE_DATA_DIR"/system-restart.svg", cd_logout_restart, pMenu);
@@ -373,11 +373,12 @@ static GtkWidget *_build_menu (void)
 static void _display_menu (void)
 {
 	// build and show the menu
-	GtkWidget *pMenu = _build_menu ();
+	GtkWidget *pShutdownMenuItem = NULL;
+	GtkWidget *pMenu = _build_menu (&pShutdownMenuItem);
 	CD_APPLET_POPUP_MENU_ON_MY_ICON (pMenu);
 	
 	// select the first (or last) item, which corresponds to the 'shutdown' action.
-	gtk_menu_shell_select_item (GTK_MENU_SHELL (pMenu), pShutdownMenuItem);
+	gtk_menu_shell_select_item (GTK_MENU_SHELL (pMenu), pShutdownMenuItem);  // must be done here, after the menu has been realized.
 }
 
 
