@@ -23,8 +23,13 @@
 
 #include <cairo-dock.h>
 
+#if GTK_CHECK_VERSION (3, 6, 0)
+#define GTK_BOOKMARKS_PATH ".config/gtk-3.0/bookmarks"
+#else
+#define GTK_BOOKMARKS_PATH ".gtk-bookmarks"
+#endif
 
-void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gchar *cURI, CairoDockModuleInstance *myApplet);
+void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gchar *cURI, GldiModuleInstance *myApplet);
 
 
 void cd_shortcuts_remove_one_bookmark (const gchar *cURI);
@@ -34,7 +39,7 @@ void cd_shortcuts_rename_one_bookmark (const gchar *cURI, const gchar *cName);
 void cd_shortcuts_add_one_bookmark (const gchar *cURI);
 
 
-GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath);
+GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, GldiModuleInstance *myApplet);
 
 
 #endif
